#!/bin/bash
#
# source location : http://downloads.sourceforge.net/libetpan/libetpan-0.57.tar.gz
#
# packager : gmg (gerard.monpontet@orange.fr)
# 

#------------------Set Some Variables

soft="libetpan"
softversion="0.57"
arch="i486"
cpu="i686"
packageversion="54.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.gz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvzf $srcpkg
rm -f $dest.tgz
rm -rf $dest
mkdir -p $dest/install

#-----------------Make the slack-desc files

cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

        |-----handy-ruler--------------------------------------------------------|
libetpan: libetpan (libEtPan is a mail purpose library).
libetpan:
libetpan: libEtPan ! is a mail purpose library. It will be used for low-level
libetpan: mail handlingprotocols (IMAP/NNTP/POP3/SMTP over TCP/IP and SSL/TCP/IP,
libetpan: already implemented), local storage (mbox/MH/maildir), message / MIME
libetpan: parser. message / MIME parser
libetpan:
libetpan:
libetpan:
libetpan:
libetpan:
EODESC

#------------------Set correct permissions

cd $src

chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

#------------------Start Configure

export CFLAGS="-O2 -march=$arch -mtune=$cpu" \
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu" \

./configure \
  --prefix=/usr \
  --disable-static

make -j2
make install DESTDIR=$dest

#-------------------Prepare the documentation:

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a ChangeLog COPYRIGHT NEWS $dest/usr/doc/$soft-$softversion

( cd $dest
  find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
  find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.tgz
cd $buildir
md5sum $package.tgz > $package.md5